@@ -1,6 +1,6 @@
 // Filename: component_config.rs
-// Version:	 0.10
-// Date:	 24-09-2021 (DD-MM-YYYY)
+// Version:	 0.11
+// Date:	 11-11-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -35,6 +35,8 @@ mod pipeline;
 #[doc(hidden)]
 mod register_file;
 #[doc(hidden)]
+mod reorder_buffer;
+#[doc(hidden)]
 mod scheduler;
 
 pub use cache::{CacheConfig, CacheType};
@@ -44,4 +46,5 @@ pub use load_store_unit::LoadStoreUnitConfig;
 pub use memory_controller::MemoryControllerConfig;
 pub use pipeline::{AluCapabilities, PipelineConfig};
 pub use register_file::RegisterFileConfig;
+pub use reorder_buffer::ReorderBufferConfig;
 pub use scheduler::SchedulerConfig;
