@@ -1,6 +1,6 @@
 // Filename: decoder.rs
-// Version:	 0.1
-// Date:	 24-09-2021 (DD-MM-YYYY)
+// Version:	 0.2
+// Date:	 11-10-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -25,7 +25,7 @@ use serde::{Deserialize, Serialize};
 /// Properties of the decode stage.
 ///
 /// It is responsible for decoding memory into executable instructions.
-#[derive(Default, Deserialize, Serialize)]
+#[derive(Clone, Default, Deserialize, Serialize)]
 pub struct DecodeConfig {
     /// How many instructions can be decoded in one clock cycle.
     pub width: usize,
