@@ -1,6 +1,6 @@
 // Filename: memory_controller.rs
-// Version:	 0.2
-// Date:	 27-07-2021 (DD-MM-YYYY)
+// Version:	 0.3
+// Date:	 11-10-2021 (DD-MM-YYYY)
 //
 // Copyright (c) 2021 Kai Rese
 // This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,7 @@ use serde::{Deserialize, Serialize};
 /// Properties of the memory controller.
 ///
 /// It acts as the root of memory, providing data to the CPU and its caches, if it has some.
-#[derive(Deserialize, Serialize)]
+#[derive(Clone, Deserialize, Serialize)]
 pub struct MemoryControllerConfig {
     /// How many clock cycles a request takes before the response is sent.
     pub access_latency: usize,
