@@ -1,6 +1,6 @@
 // Filename: scheduler.rs
-// Version:	 0.1
-// Date:	 15-09-2021 (DD-MM-YYYY)
+// Version:	 0.2
+// Date:	 11-10-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -21,7 +21,7 @@
 use serde::{Deserialize, Serialize};
 
 /// The properties of a scheduler.
-#[derive(Default, Deserialize, Serialize)]
+#[derive(Clone, Default, Deserialize, Serialize)]
 pub struct SchedulerConfig {
     /// The identification number. Used for connecting pipelines.
     pub id: usize,
